Learn R Programming

calibmsm (version 1.1.3)

msebmtcal: European Group for Blood and Marrow Transplantation data in msdata format.

Description

The ebmt4 data converted into msdata format (see msprep), using the processes implemented in the mstate package. Code for the derivation of this dataset is provided in the source code for the package.

Usage

msebmtcal

Arguments

Format

'msebmtcal'

A data frame in msdata format (see msprep) with 15,512 rows and 8 columns:

id

Patient indentifier

from

transition from state

to

transition to state

trans

transition number

Tstart

time entered state 'from'

Tstop

time leaving state 'from'

time

time in state 'from'

status

event indicator, 1:transitioned to state 'to'

References

EBMT (2023). “Data from the European Society for Blood and Marrow Transplantation.” URL https://search.r-project.org/CRAN/refmans/mstate/html/EBMT-data.html.

de Wreede LC, Fiocco M, Putter H (2011). “mstate: An R Package for the Analysis of Competing Risks and Multi-State Models.” Journal of Statistical Software, 38(7).