Learn R Programming

calibmsm (version 1.1.3)

msebmtcal_cmprsk: European Group for Blood and Marrow Transplantation data in competing risks format, for transitions out of the initial state only

Description

Used in vignette/article: Comparison-with-graphical-calibration-curves-in-competing-risks-setting.

Usage

msebmtcal_cmprsk

Arguments

Format

'msebmtcal_cmprsk'

A data frame with 9,116 rows and 8 columns:

id

Patient indentifier

from

transition from state

to

transition to state

trans

transition number

Tstart

time entered state 'from'

Tstop

time leaving state 'from'

time

time in state 'from'

status

event indicator, 1:transitioned to state 'to'

Details

The ebmt4 data converted into msdata format (see msprep), where all subsequent states are considered absorbing states. i.e. only transitions out of the initial state are considered, meaning this data constitutes a competing risks model out of the initial state. Code for the derivation of this dataset is provided in the source code for the package.

References

EBMT (2023). “Data from the European Society for Blood and Marrow Transplantation.” URL https://search.r-project.org/CRAN/refmans/mstate/html/EBMT-data.html.

de Wreede LC, Fiocco M, Putter H (2011). “mstate: An R Package for the Analysis of Competing Risks and Multi-State Models.” Journal of Statistical Software, 38(7).