Used in vignette/article: Comparison-with-graphical-calibration-curves-in-competing-risks-setting.
tp_cmprsk_j0
A data frame with 2,279 rows and 13 columns:
Patient indentifier
Predicted transition probabilities of transitions into states 1 to 6
Standard error of the predicted transition probabilities of transitions into states 1 to 6
Data frame containing the predicted transition probabilities out of state j = 1
made at time s = 0, for a competing risks model out of the initial state (see msebmtcal_cmprsk).
The predicted transition probabilities were estimated by fitting
a competing risks model to the msebmtcal_cmprsk data using a leave-one-out approach.
Code for deriving this dataset is provided in the source code for calibmsm. Code for the derivation
of this dataset is provided in the source code for the package.
EBMT (2023). “Data from the European Society for Blood and Marrow Transplantation.” URL https://search.r-project.org/CRAN/refmans/mstate/html/EBMT-data.html.
de Wreede LC, Fiocco M, Putter H (2011). “mstate: An R Package for the Analysis of Competing Risks and Multi-State Models.” Journal of Statistical Software, 38(7).