msdata format.The ebmt4 data converted into msdata format (see msprep),
using the processes implemented in the mstate package. Code for the derivation
of this dataset is provided in the source code for the package.
msebmtcal
A data frame in msdata format (see msprep) with 15,512 rows and 8 columns:
Patient indentifier
transition from state
transition to state
transition number
time entered state 'from'
time leaving state 'from'
time in state 'from'
event indicator, 1:transitioned to state 'to'
EBMT (2023). “Data from the European Society for Blood and Marrow Transplantation.” URL https://search.r-project.org/CRAN/refmans/mstate/html/EBMT-data.html.
de Wreede LC, Fiocco M, Putter H (2011). “mstate: An R Package for the Analysis of Competing Risks and Multi-State Models.” Journal of Statistical Software, 38(7).