Used in vignette/article: Comparison-with-graphical-calibration-curves-in-competing-risks-setting.
msebmtcal_cmprsk
A data frame with 9,116 rows and 8 columns:
Patient indentifier
transition from state
transition to state
transition number
time entered state 'from'
time leaving state 'from'
time in state 'from'
event indicator, 1:transitioned to state 'to'
The ebmt4 data converted into msdata format (see msprep),
where all subsequent states are considered absorbing states. i.e. only transitions out of the initial state are considered,
meaning this data constitutes a competing risks model out of the initial state. Code for the derivation
of this dataset is provided in the source code for the package.
EBMT (2023). “Data from the European Society for Blood and Marrow Transplantation.” URL https://search.r-project.org/CRAN/refmans/mstate/html/EBMT-data.html.
de Wreede LC, Fiocco M, Putter H (2011). “mstate: An R Package for the Analysis of Competing Risks and Multi-State Models.” Journal of Statistical Software, 38(7).