Data frame containing the predicted transition probabilities out of state j = 1
made at time s = 0. The predicted transition probabilities were estimated by fitting
a multistate model to the ebmt4 data using a leave-one-out approach.
Code for deriving this dataset is provided in the source code for calibmsm. Code for the derivation
of this dataset is provided in the source code for the package.
tps0
A data frame with 13,674 (CHANGE) rows and 14 columns:
Patient indentifier
Predicted transition probabilities of transitions into states 1 to 6
Standard error of the predicted transition probabilities of transitions into states 1 to 6
State from which the predicted transition probabilities are estimated from
EBMT (2023). “Data from the European Society for Blood and Marrow Transplantation.” URL https://search.r-project.org/CRAN/refmans/mstate/html/EBMT-data.html.
de Wreede LC, Fiocco M, Putter H (2011). “mstate: An R Package for the Analysis of Competing Risks and Multi-State Models.” Journal of Statistical Software, 38(7).